@@ -114,7 +114,8 @@ class ImportDialog(BaseImportDialog):
 
     def get_data(self):
         root = NXroot()
-        specmin, specmax = self.get_spectra
+        self.import_file = self.get_filename()
+        specmin, specmax = self.get_spectra()
         for i in self.spectra[0:specmax]:
             scan = self.SPECfile.getScan(i)
             if i < self.spectra[specmin]:
